@@ -251,3 +251,7 @@ class Ensemble(APIResource):
                 result['Permutation'].pop('_title')
             if result.get('Permutation', {}).get('_description'):
                 result['Permutation'].pop('_description')
+
+    @classmethod
+    def get_ensemble_id(cls, search_term=None) -> WhatifyResponse:
+        return cls.list(search_term=search_term)['hits'][0]['id']
