@@ -9,7 +9,6 @@ from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.token_json import UserToken
 from toolkit_w.internal.vars_global import ProblemType, TargetMetric, FeatureType
 from toolkit_w.internal.vars_global import InterpretabilityLevel as Interpt
-from toolkit_w.resources.auth import authenticate
 import toolkit_w as my_toolkit
 
 logging.getLogger().setLevel(logging.INFO)
@@ -34,12 +33,31 @@ class MyWhatify:
     def authenticate(self, username, password):
         self.login(email=username,password=password)
 
-    def login(self, email, password):
+    def login(self, email, password, user_id: str = None):
         with allure.step('login with user: ' + str(email)):
             logging.info('login with user: ' + str(email))  # + ' and password: ' + password)
-            authenticate(username=email, password=password)
+            my_toolkit.UserManagement.login(email=email, password=password)
+            if user_id:
+                with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
+                    my_toolkit.UserManagement.impersonate(user_id=user_id)
             self.user_token = UserToken(my_toolkit.token)
-            print("{} - Login successful".format(str(email)))
+
+
+    def get_user_id(self, email: str = None):
+        user_id = -1
+        with allure.step('get user ID for current user or for user: ' + str(email)):
+            logging.info('get user ID for current user or for user: ' + str(email))
+            if email:
+                raise Exception('Need to implement')
+                user_id = 1
+            else:
+                user_id = self.user_token.get_user_id()
+
+        return user_id
+
+    def impersonate(self, user_id, email: str = None, admin_token: str = None):
+        with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
+            my_toolkit.UserManagement.impersonate(email=email, user_id=user_id, admin_token=admin_token)
 
     def mark_ensemble_in_production(self, ensemble_id, mark_production=True):
         with allure.step('setting ensemble_id: ' + str(ensemble_id) + ' as in production: ' + str(mark_production)):
@@ -249,20 +267,25 @@ class MyWhatify:
         logging.info('getting the Tasks list for data_name: ' + str(data_name))
         return my_toolkit.Task.list(search_term=data_name)['hits']
 
-    def get_tasks_list(self, len=10):
+    def get_tasks_list(self, len=10, search_term=None):
         with allure.step('getting the tasks list with len: ' + str(len)):
-            list_tasks = my_toolkit.Task.list()
+            list_tasks = my_toolkit.Task.list(search_term=search_term)
             tasks = pd.DataFrame(list_tasks['hits'])
-
-            tasks.columns
-        return tasks[['creation_date', 'dataset_id', 'name', 'notes', 'problem_type',
-               'state', 'target_metric']].head(len)
+        return tasks[['creation_date', 'dataset_id', 'name', 'notes', 'problem_type', 'state', 'target_metric']].head(len)
 
     def get_ensemble_list(self, task_id):
         with allure.step('getting the Ensemble list for task ID: ' + str(task_id)):
             # get list of ensembles
             return my_toolkit.Ensemble.list(filter_={'task_id': [task_id], 'stage': ['TASK', 'REFIT']})['hits']
 
+    def get_ensemble_id(self, task_name):
+        with allure.step('getting the ensemble ID of task name: ' + str(task_name)):
+            ensemble_id = my_toolkit.Ensemble.get_ensemble_id(search_term=task_name)
+            # task_id = self.get_tasks_list(search_term=task_name) 151231
+            # task_id = task_id[-1]['id']
+            # ensemble_id = self.get_ensemble_list(task_id=task_id)[-1]['id']
+            return ensemble_id
+
     def get_data_file(self, data_name='car_sdk_demo.csv'):
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
             script_dir = os.path.dirname(__file__)
